@@ -1,6 +1,6 @@
 #### PostScript Goodies fr R --- `a la /u/sfs/S/ps.goodies.S
 ####
-#### $Id: ps.goodies.R,v 1.20 2013/11/18 10:47:03 maechler Exp $
+#### $Id: ps.goodies.R,v 1.21 2014/04/23 18:01:57 maechler Exp $
 ####
 
 ## hidden in the name space -- FIXME? maybe more useful ?? ---
@@ -262,3 +262,8 @@ pdf.end <- function(call.viewer = NULL, command = getOption("pdfviewer"),
     }
     invisible(fil)
 }
+
+## Alain Hauser <alain@huschhus.ch> --> ../man/cairoSwd.Rd
+cairoSwd <- function(name, width, height, ...)
+  cairo_pdf(filename = paste(name, "pdf", sep = "."),
+            width = width, height = height, ...)
